@@ -163,7 +163,8 @@ class FlaviusData(FlaviusBase):
     """
     def __init__(self):
         super(FlaviusData, self).__init__(search_url='', create_url=conf.FLAVIUS_API_DATA_CREATE,
-                                          update_url='', delete_url='')
+                                          update_url=conf.FLAVIUS_API_DATA_UPDATE,
+                                          delete_url=conf.FLAVIUS_API_DATA_DELETE)
 
 
 class FlaviusPage(FlaviusBase):
