@@ -58,6 +58,14 @@ class Settings:
     def FLAVIUS_API_DATA_CREATE(self):
         return getattr(settings, "FLAVIUS_API_DATA_CREATE", 'api/data_add.php')
 
+    @property
+    def FLAVIUS_API_DATA_UPDATE(self):
+        return getattr(settings, "FLAVIUS_API_DATA_UPDATE", 'api/data_modify.php')
+
+    @property
+    def FLAVIUS_API_DATA_DELETE(self):
+        return getattr(settings, "FLAVIUS_API_DATA_DELETE", 'api/data_delete.php')
+
     @property
     def FLAVIUS_API_PAGE_FETCH(self):
         return getattr(settings, "FLAVIUS_API_PAGE_FETCH", 'api/pages.php')
